"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_extra_1 = require("fs-extra");
const element_1 = require("../utils/element");
const utils_1 = require("./utils");
let vBrowser;
let metadata;
let html;
let savedPage;
let childFrame;
beforeAll(async () => {
    await utils_1.removeResources();
    vBrowser = await utils_1.launch();
    const vPage = await vBrowser.newPage();
    await vPage.goto(utils_1.servedFileURL('page.html'));
    const clipped = await vPage.clip();
    await vPage.close();
    metadata = clipped.metadata;
    html = clipped.html;
});
beforeEach(async () => {
    savedPage = (await vBrowser.newPage()).frame;
    await savedPage.setContent(html);
    childFrame = savedPage.frames()[1];
});
afterEach(async () => {
    await savedPage.close();
});
afterAll(async (done) => {
    await utils_1.removeResources();
    await vBrowser.close();
    done();
});
test('resource db', async () => {
    const file = await fs_extra_1.readFile(utils_1.resourceDBPath, 'utf8');
    expect(JSON.parse(file)).toEqual({
        'http:!!localhost:3000!icon.png': {
            url: 'http://localhost:3000/icon.png',
            versions: [
                expect.objectContaining({
                    createdAt: expect.stringMatching(/^\d{4}-/),
                    hash: expect.stringMatching(/^.{64}$/),
                    path: expect.stringMatching(/^.{26}\/.{26}\.png$/),
                }),
            ],
        },
    });
});
test('metadata', async () => {
    expect(metadata).toMatchObject({
        _version: 1,
        domain: 'localhost',
        hostname: 'localhost',
        url: utils_1.servedFileURL('page'),
        title: 'Vanilla Test',
    });
});
test('element count', async () => {
    await expect(savedPage.$$(`link[rel=stylesheet], [src]:not(${element_1.buildVAttrSelector.src()}):not(a)`)).resolves.toHaveLength(0);
    await expect(savedPage.$$(`head style${element_1.buildVAttrSelector.style()}`)).resolves.toHaveLength(2);
    await expect(savedPage.$$(`head script${element_1.buildVAttrSelector.script()}`)).resolves.toHaveLength(1);
    await expect(savedPage.$$(`body img${element_1.buildVAttrSelector.src(utils_1.servedFileURL('icon.png'))}`)).resolves.toHaveLength(1);
});
test('style[data-vanilla-clipper-style] content', async () => {
    const texts = await savedPage.$$eval(`head style${element_1.buildVAttrSelector.style()}`, els => els.map(el => el.innerHTML));
    expect(texts).toEqual([
        expect.stringContaining('.external'),
        expect.stringContaining('.style-tag'),
    ]);
});
test('[src] attribute', async () => {
    const src = await savedPage.$eval(`img${element_1.buildVAttrSelector.src()}`, img => img.getAttribute('src'));
    expect(src).toMatch(/\.\.\/resources\/.{26}\/.{26}\.png/);
});
test('iframe - element count', async () => {
    await expect(childFrame.$$(`link[rel=stylesheet], [src]:not(${element_1.buildVAttrSelector.src()}):not(a)`)).resolves.toHaveLength(0);
    await expect(childFrame.$$(`head style${element_1.buildVAttrSelector.style()}`)).resolves.toHaveLength(2);
    await expect(childFrame.$$(`head script${element_1.buildVAttrSelector.script()}`)).resolves.toHaveLength(1);
    await expect(childFrame.$$(`body img${element_1.buildVAttrSelector.src(utils_1.servedFileURL('icon.png'))}`)).resolves.toHaveLength(1);
});
//# sourceMappingURL=VPage.test.js.map