"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const css_tree_1 = __importDefault(require("css-tree"));
const fs_extra_1 = require("fs-extra");
const jsdom_1 = require("jsdom");
const css_1 = require("../utils/css");
const utils_1 = require("./utils");
const iconURL = utils_1.servedFileURL('icon.png');
const cssURL = utils_1.servedFileURL('main.css');
const iconBuffer = fs_extra_1.readFileSync(utils_1.publicFilePath('icon.png'));
const iconDataURL = `data:image/png;base64,${iconBuffer.toString('base64')}`;
const cssFileText = fs_extra_1.readFileSync(utils_1.publicFilePath('main.css'), 'utf8');
describe('optimizeCSS()', () => {
    const { window } = new jsdom_1.JSDOM();
    test('extract woff2 and local', async () => {
        const optimized = await css_1.optimizeCSS({
            text: `@font-face {
                    font-family: 'Awesome Font';
                    src: url(/fonts/awesome.woff) format('woff');
                    src:
                        url(/fonts/awesome.otf) format('opentype'),
                        local('Awesome Font'),
                        url(/fonts/awesome.woff2) format('woff2'),
                        url(/fonts/awesome.eot) format('embedded-opentype');
                }`,
            url: '',
        }, window.document, true);
        const fontURL = '/fonts/awesome.woff2';
        expect(optimized).toEqual(css_tree_1.default.generate(css_tree_1.default.parse(`@font-face {
                    src:
                        local('Awesome Font'),
                        url(${fontURL}) format('woff2');
                    font-family: 'Awesome Font';
                }`)));
    });
    test('extract woff - without quotes and format name', async () => {
        const fontURL = '/fonts/awesome.woff';
        expect(await css_1.optimizeCSS({
            text: `@font-face {
                        font-family: 'Awesome Font';
                        src:
                            url(/fonts/awesome.otf) format('opentype'),
                            url(/fonts/awesome.woff),
                            url(/fonts/awesome.eot) format('embedded-opentype');
                    }`,
            url: '',
        }, window.document, true)).toEqual(css_tree_1.default.generate(css_tree_1.default.parse(`@font-face {
                    src: url(${fontURL}) format('woff');
                    font-family: 'Awesome Font';
                }`)));
    });
});
test('extractOrFetchCSSText()', async () => {
    const text = '.text { opacity: 1; }';
    const sheets = await css_1.extractOrFetchCSS([
        { type: 'text', url: utils_1.servedFileURL(''), text },
        { type: 'link', url: cssURL },
    ]);
    expect(sheets).toEqual([
        { text: text, url: utils_1.servedFileURL('') },
        { text: cssFileText, url: cssURL },
    ]);
});
//# sourceMappingURL=utils.css.test.js.map