"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const jsdom_1 = require("jsdom");
const document_1 = require("../utils/document");
const element_1 = require("../utils/element");
const createDocument = (html) => new jsdom_1.JSDOM(html).window.document;
const src = '/src-path';
const href = '/href-path';
test('embedIFrameContents()', () => {
    const html = 'iframe content';
    const uuid = '1234';
    const document = createDocument(`
        <html>
            <body>
                <iframe src="${src}" data-vanilla-clipper-iframe-uuid=${uuid}></iframe>
            </body>
        </html>
    `);
    const finder = element_1.createElementFinder(document);
    const iframes = document_1.embedIFrameContents(finder, [{ uuid, html }]);
    expect(iframes).toHaveLength(1);
    expect(iframes[0]).toMatchObject({
        src: '',
        srcdoc: html,
    });
    expect(iframes[0].dataset).toMatchObject({ vanillaClipperSrc: src });
});
test('moveAttrToDatasetAndReturnURLs()', () => {
    const document = createDocument(`
        <html>
            <body>
                <img src="${src}" />
                <img src="data:image/png;base64," />
                <link href="${href}"></a>
                <link href="data:text/css;base64,"></a>
            </body>
        </html>
    `);
    const finder = element_1.createElementFinder(document);
    const urls = document_1.moveAttrToDatasetAndReturnURLs(finder);
    expect(urls).toEqual(new Set([href, src]));
    expect(finder({ selector: element_1.getVAttrSelector.src(src), not: ['[src]'] })).toHaveLength(1);
    expect(finder({ selector: element_1.getVAttrSelector.href(href), not: ['[href]'] })).toHaveLength(1);
});
test('appendScriptToHead()', () => {
    const document = createDocument(`
        <html>
            <head></head>
            <body></body>
        </html>
    `);
    const script = "console.log('script')";
    document_1.appendScriptToHead(document, script);
    expect(document.head.querySelector(element_1.getVAttrSelector.script()).innerHTML).toBe(script);
});
//# sourceMappingURL=utils.document.test.js.map