"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const rain_1 = require("@yarnaimo/rain");
const tldjs_1 = require("tldjs");
const utils_1 = require("../utils");
class Sites {
    constructor(siteDataList) {
        this.siteDataList = siteDataList;
        this.sites = siteDataList;
    }
    findSite(url) {
        return this.sites.find(s => tldjs_1.getDomain(s.url) === tldjs_1.getDomain(url));
    }
    async login(site, vPage, accountLabel = 'default') {
        const account = site.accounts[accountLabel];
        if (!account) {
            utils_1.sig.warn(`Account "${accountLabel}" not found`);
            return;
        }
        if (account.isLoggedIn) {
            return;
        }
        utils_1.sig.await('Logging in with account "%s"', accountLabel);
        await site.login.reduce(async (prevPromise, [action, ...args]) => {
            await prevPromise;
            if (!action) {
                return;
            }
            const computedArgs = await rain_1.Rarray.waitAll(args, async (a) => {
                if (!a.startsWith('$')) {
                    return a;
                }
                const value = account[a.slice(1)];
                return rain_1.is.undefined(value)
                    ? ''
                    : rain_1.is.boolean(value)
                        ? String(value)
                        : rain_1.is.string(value)
                            ? value
                            : value();
            });
            try {
                switch (action) {
                    case 'goto':
                        await vPage.frame.goto(computedArgs[0]);
                        await vPage.frame.waitFor(2000);
                        break;
                    case 'focus':
                        await vPage.frame.focus(computedArgs[0]);
                        break;
                    case 'input':
                        await vPage.frame.type(computedArgs[0], computedArgs[1]);
                        break;
                    case 'click':
                        await vPage.frame.click(computedArgs[0]);
                        break;
                    case 'submit':
                        await vPage.frame.waitFor(1000);
                        await Promise.all([
                            vPage.frame.waitForNavigation({ waitUntil: 'networkidle2' }),
                            vPage.frame.click(computedArgs[0]),
                        ]);
                        await vPage.frame.waitFor(1000);
                        break;
                    default:
                }
            }
            catch (error) {
                utils_1.sig.error(error);
            }
        }, Promise.resolve());
        account.isLoggedIn = true;
    }
}
exports.Sites = Sites;
//# sourceMappingURL=site.js.map