"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
const rain_1 = require("@yarnaimo/rain");
const fs_extra_1 = require("fs-extra");
const utils_1 = require("../utils");
const VPage_1 = require("./VPage");
const isTest = process.env.NODE_ENV === 'test';
const puppeteer = require(isTest ? 'puppeteer' : 'puppeteer-core');
class VBrowser {
    constructor(browser) {
        this.browser = browser;
    }
    static async clipPages({ verbose, noSandbox, headless, language, device, userDataDir, }, list) {
        const vBrowser = await VBrowser.launch(noSandbox, { userDataDir, headless, dumpio: verbose }, language);
        const vPage = await vBrowser.newPage(device);
        const successCount = await list.reduce(async (prevPromise, _a, i) => {
            var { url, accountLabel, outputPath } = _a, options = __rest(_a, ["url", "accountLabel", "outputPath"]);
            const _successCount = await prevPromise;
            utils_1.sig.pending('[%d/%d] Clipping %s', i + 1, list.length, url);
            try {
                await vPage.goto(url, accountLabel);
                const { html, metadata } = await vPage.clip(options);
                const _outputPath = rain_1.is.string(outputPath)
                    ? outputPath
                    : await outputPath(metadata);
                await fs_extra_1.outputFile(_outputPath, html);
                utils_1.sig.success('Saved as %s', _outputPath);
                return _successCount + 1;
            }
            catch (error) {
                utils_1.sig.error(error);
                return _successCount;
            }
        }, Promise.resolve(0));
        await vPage.close();
        if (successCount) {
            utils_1.sig.complete('Clipped %d page%s', successCount, successCount === 1 ? '' : 's');
        }
        await vBrowser.close();
    }
    static async launch(noSandbox = false, _a = {}, lang) {
        var { args = [] } = _a, options = __rest(_a, ["args"]);
        if (lang) {
            args.push(`--lang=${lang}`);
        }
        let executablePath;
        let userDataDir;
        if (!rain_1.is.undefined(options.executablePath)) {
            executablePath = options.executablePath;
            utils_1.sig.info('Using %s', executablePath);
        }
        else {
            executablePath = utils_1.findChrome();
        }
        if (options.userDataDir) {
            userDataDir = options.userDataDir;
            fs_extra_1.ensureDir(userDataDir);
            utils_1.sig.info('User Data Directory: %s', userDataDir);
        }
        const browser = await puppeteer.launch(Object.assign({ ignoreHTTPSErrors: true, executablePath,
            userDataDir }, options, { args: [...args, ...(noSandbox ? utils_1.noSandboxArgs : [])] }));
        return new VBrowser(browser);
    }
    async newPage(device) {
        const vPage = new VPage_1.VPage(this, await this.browser.newPage());
        await vPage.frame.setCacheEnabled(false);
        if (device) {
            await vPage.frame.emulate(device);
        }
        return vPage;
    }
    async close() {
        await this.browser.close();
    }
}
exports.VBrowser = VBrowser;
//# sourceMappingURL=VBrowser.js.map