"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const css_1 = require("../utils/css");
const VDocument_1 = require("./VDocument");
const VJsdom_1 = require("./VJsdom");
const VPage_1 = require("./VPage");
class VFrame {
    constructor(vBrowser, frame) {
        this.vBrowser = vBrowser;
        this.frame = frame;
        this.isRoot = false;
    }
    async clip({ element, click, scroll, maxScrolls = 10 } = {}) {
        const originalDocument = await VDocument_1.VDocument.create(this, () => document);
        const height = await originalDocument.scrollToBottom({ element, scroll, maxScrolls });
        if (this instanceof VPage_1.VPage) {
            await this.setViewportHeight(height);
            await this.frame.waitFor(3000);
        }
        if (click) {
            await originalDocument.click(click);
        }
        await originalDocument.setUuidToIFramesAndShadowHosts();
        await originalDocument.replaceObjectURLsWithDataURL();
        await originalDocument.embedContentOfShadowDOMs();
        const { html: originalHTML, location } = await originalDocument.getHTML();
        const sheetDataList = await originalDocument.getSheetDataList();
        const dom = new VJsdom_1.VJsdom(originalHTML, { url: location.href });
        if (element) {
            dom.setElementAsRoot(element);
        }
        dom.execPlugins();
        const m = location.href.match(/https:\/\/mobile\.twitter\.com\/.+\/status\/(\d+)/);
        if (m) {
            await dom.embedTwitterVideo(m[1]);
        }
        await Promise.all([
            (async () => {
                const iframes = dom.getIframes();
                const iframeDataList = await originalDocument.clipIframes(iframes);
                dom.embedIFrameContents(iframeDataList);
            })(),
            (async () => {
                await dom.processResourcesInAttrs();
                const sheets = await css_1.extractOrFetchCSS(sheetDataList);
                const optimized = await Promise.all(sheets.map(sheet => css_1.optimizeCSS(sheet, dom.document)));
                dom.appendStyleSheets(optimized);
                dom.appendScriptToHead();
            })(),
        ]);
        if (this instanceof VPage_1.VPage) {
            await this.resetViewport();
        }
        return dom.generate(this.isRoot);
    }
}
exports.VFrame = VFrame;
//# sourceMappingURL=VFrame.js.map