"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
require("mime-types");
const node_json_db_1 = __importDefault(require("node-json-db"));
const path_1 = require("path");
const config_store_1 = require("../config-store");
const utils_1 = require("../utils");
const db = new node_json_db_1.default(path_1.resolve(utils_1.dataDirectoryPath, 'resources.json'), true, false);
class Resource {
    constructor() {
        this.versions = [];
    }
    static _get(url) {
        const resource = new Resource();
        try {
            const data = db.getData(url);
            Object.assign(resource, data);
        }
        catch (error) { }
        return resource;
    }
    static async store(url) {
        const resource = this._get(url);
        try {
            const { headers: { 'content-type': mimetype, 'content-length': size }, } = await utils_1.got.head(url);
            if (size && parseInt(size) > config_store_1.config.resource.maxSize) {
                return;
            }
            const { body } = await utils_1.got.get(url, { encoding: null });
            if (body.length > config_store_1.config.resource.maxSize) {
                return;
            }
            const hash = utils_1.getHash(body);
            const matchedVersion = resource.versions.find(v => v.hash === hash);
            if (matchedVersion) {
                return matchedVersion.path;
            }
        }
        catch (error) {
            return `data:text/css,${commentOutError(error)}`;
        }
        db.push(`/${url}`);
    }
}
exports.Resource = Resource;
//# sourceMappingURL=Resource.js.map