"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const rain_1 = require("@yarnaimo/rain");
const url_1 = require("url");
const _1 = require(".");
const css_1 = require("./css");
const element_1 = require("./element");
exports.dataURLPattern = /^data:[\w\/\+]+(?:;.*)?,/;
async function extractOrFetchCSS(sheetDataList) {
    const sheets = await rain_1.Rarray.waitAll(sheetDataList, async (data) => {
        try {
            if (data.type === 'error')
                throw data.error;
            if (data.type === 'text')
                return css_1.replaceRelativeURLsInCSS(data.text, data.url);
            const { body } = await _1.got.get(data.url);
            return css_1.replaceRelativeURLsInCSS(body, data.url);
        }
        catch (_error) {
            return _1.commentOutError(_error);
        }
    });
    return sheets;
}
exports.extractOrFetchCSS = extractOrFetchCSS;
async function dataSourceURLsToDataList(dataSourceURLs, currentURL) {
    const urls = dataSourceURLs.reduce((prev, current) => [...prev, ...current], []);
    return rain_1.Rarray.waitAll(urls, async (url) => {
        const dataURL = await getDataURL(url, currentURL);
        return [url, dataURL];
    });
}
exports.dataSourceURLsToDataList = dataSourceURLsToDataList;
function dataListToScriptString(dataList, cssTexts) {
    const dataElementSelector = `${element_1.buildVAttrSelector.src()}, ${element_1.buildVAttrSelector.href()}`;
    const videoElementSelector = `${element_1.buildVAttrSelector.video()}`;
    const _cssURLPattern = css_1.cssURLPattern;
    async function main() {
        const objectURLMap = new Map(await Promise.all(dataList.map(async ([url, dataURL]) => {
            const blob = await fetch(dataURL).then(res => res.blob());
            return [url, URL.createObjectURL(blob)];
        })));
        const styleElements = cssTexts
            .map(text => text.replace(_cssURLPattern, (_, prefix, url) => `${prefix}('${objectURLMap.get(url)}')`))
            .map(text => {
            const el = document.createElement('style');
            el.dataset.vanillaClipperStyle = '';
            el.innerHTML = text;
            return el;
        });
        document.head.append(...styleElements);
        if (document.readyState === 'loading') {
            document.addEventListener('DOMContentLoaded', onload);
        }
        else {
            onload();
        }
        function onload() {
            const dataElements = document.querySelectorAll(dataElementSelector);
            dataElements.forEach(el => {
                const { vanillaClipperSrc, vanillaClipperHref } = el.dataset;
                const src = objectURLMap.get(vanillaClipperSrc);
                const href = objectURLMap.get(vanillaClipperHref);
                if (src)
                    el.setAttribute('src', src);
                if (href)
                    el.setAttribute('href', href);
            });
            const videoElement = document.querySelector(videoElementSelector);
            if (videoElement) {
                const playOrPause = () => videoElement.paused ? videoElement.play() : videoElement.pause();
                videoElement.onclick = playOrPause;
                document.body.onkeypress = () => {
                    if (window.event.keyCode === 32) {
                        ;
                        window.event.preventDefault();
                        playOrPause();
                    }
                };
            }
        }
    }
    return `
        const _cssURLPattern = ${_cssURLPattern.toString()}
        const dataList = ${JSON.stringify(dataList)}
        const cssTexts = ${JSON.stringify(cssTexts)}
        const dataElementSelector = '${dataElementSelector}'
        const videoElementSelector = '${videoElementSelector}'

        ${main.toString()}
        main()
    `;
}
exports.dataListToScriptString = dataListToScriptString;
async function getDataURL(url, currentURL) {
    try {
        const { body, headers: { 'content-type': mimetype }, } = await _1.got.get(currentURL ? url_1.resolve(currentURL, url) : url, { encoding: null });
        return `data:${mimetype};base64,${body.toString('base64')}`;
    }
    catch (error) {
        return `data:text/css,${_1.commentOutError(error)}`;
    }
}
exports.getDataURL = getDataURL;
//# sourceMappingURL=data.js.map