"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const crypto_1 = require("crypto");
const fs_extra_1 = require("fs-extra");
const luxon_1 = require("luxon");
const os_1 = require("os");
const path_1 = require("path");
const __1 = require("..");
exports.dataURLPattern = /^data:([\w\/\+]+)(?:;.*)?,(.*)$/;
function dataURLToBuffer(dataURL) {
    const m = exports.dataURLPattern.exec(dataURL);
    if (!m) {
        return;
    }
    return { buffer: Buffer.from(m[2], 'base64'), mimetype: m[1] || undefined };
}
exports.dataURLToBuffer = dataURLToBuffer;
function extractExtensionFromURL(url) {
    const m = url.match(/['"]?[^?#]+\.(\w+)(?:['"]?$|\?|#)/);
    return m ? m[1] : null;
}
exports.extractExtensionFromURL = extractExtensionFromURL;
async function newFilePath(directory, basename, ext = 'html') {
    const fileList = await fs_extra_1.readdir(directory).catch(() => []);
    if (!fileList.includes(`${basename}.${ext}`)) {
        return path_1.resolve(directory, `${basename}.${ext}`);
    }
    const regex = new RegExp(`${basename}-(\\d+)\\.${ext}`);
    const numbers = fileList
        .map(name => name.match(regex))
        .filter((m) => !!m)
        .map(m => parseInt(m[1]));
    const number = Math.max(0, ...numbers) + 1;
    return path_1.resolve(directory, `${basename}-${number}.${ext}`);
}
exports.newFilePath = newFilePath;
function outputPathFn(directory) {
    const outputDir = dataPath('pages', directory);
    const dateString = luxon_1.DateTime.local().toFormat('yyyyMMdd');
    return async (metadata) => {
        const basename = `${dateString}-${__1.filenamifyUrl(metadata.url)}`;
        const outputPath = await newFilePath(outputDir, basename);
        return outputPath;
    };
}
exports.outputPathFn = outputPathFn;
const dataDirectoryName = '.vanilla-clipper';
exports.dataDirectoryInHome = path_1.resolve(os_1.homedir(), dataDirectoryName);
exports.dataDirectoryPath = (() => {
    if (process.env.NODE_ENV === 'test') {
        return path_1.resolve('tmp', '__data__');
    }
    const inCurrent = path_1.resolve(process.cwd(), dataDirectoryName);
    try {
        return fs_extra_1.statSync(inCurrent).isDirectory() ? inCurrent : exports.dataDirectoryInHome;
    }
    catch (error) {
        return exports.dataDirectoryInHome;
    }
})();
function dataPath(...pathSegments) {
    return path_1.resolve(exports.dataDirectoryPath, ...pathSegments);
}
exports.dataPath = dataPath;
function getHash(buffer) {
    const hash = crypto_1.createHash('sha256');
    hash.update(buffer);
    return hash.digest('hex');
}
exports.getHash = getHash;
//# sourceMappingURL=file.js.map